'use strict';Object.defineProperty(exports,'__esModule',{value:true});var chessground=require('chessground'),chessops=require('@publishvue/chessops');//

var script = {
  name: "Vuechessground",
  data: function data(){
    var pos = chessops.Pos();
    return {      
      pos: pos,
      board: null,
      legalsans: [],
      history: [],      
      variants: [
        {display: "Standard", key: "standard"},
        {display: "Atomic", key: "atomic"},
        {display: "Antichess", key: "antichess"},
        {display: "Racing Kings", key: "racingkings"},
        {display: "Horde", key: "horde"}
      ],
      promuci: null,
      showpromotion: false,
      prompieces: [],
      prompiecesext: []
    }
  },
  methods:{
    makemovecancel: function makemovecancel(){
      this.prompieces = [];
      this.prompiecesext = [];
      this.$refs.movetextinput.value = "";
      this.setUp();
    },
    pieceToName: function pieceToName(p){
      return {
        q: "queen",
        r: "rook",
        b: "bishop",
        n: "knight",
        k: "king",
        p: "pawn"
      }[p]
    },
    pieceToStyle: function pieceToStyle(p, fen){
      var parts = fen.split(" ");
      var turn = parts[1] == "w" ? "white" : "black";
      var name = this.pieceToName(p);
      var style = "piece " + name + " " + turn;      
      return style
    },
    step: function step(dir){
      var fen = this.pos.reportFen();
      console.log("step", dir, fen);
      var index = this.history.findIndex(function (item) { return item.fen === fen; });
      if(index < 0){
        console.error("fen not found", fen);
        return
      }
      index += dir;
      if(index < 0) { index = 0; }
      if(index >= this.history.length) { index = this.history.length - 1; }
      this.pos.setFen(this.history[index].fen);
      this.getSelectedHistory();
      this.setUp();
      this.prompieces = [];
      this.prompiecesext = [];
    },
    tobegin: function tobegin(){
      this.step(-100);
    },
    back: function back(){
      this.step(-1);
    },
    forward: function forward(){
      this.step(1);
    },
    toend: function toend(){
      this.step(100);
    },
    clickhistory: function clickhistory(ev) {
      var fen = ev.target.getAttribute("fen");      
      this.pos.setFen(fen);
      this.getSelectedHistory();            
      var itemIndex = this.history.findIndex(function (item) { return item.selected == "histactive"; });
      console.log(itemIndex, this.history[itemIndex]);
      this.recordMovePlayed(this.history[itemIndex].genSan, itemIndex > 0 ? this.history[itemIndex - 1].fen : null, true);
    },
    getSelectedHistory: function getSelectedHistory(){
      var fen = this.pos.reportFen();
      for(var i = 0, list = this.history; i < list.length; i += 1) {
        var item = list[i];

        item.selected = item.fen == fen ? "histactive" : "histpassive";
      }
    },
    recordMovePlayed: function recordMovePlayed(san, prevFen, dontAdd){      
      var fen = this.pos.reportFen();            

      if(!dontAdd){
        var index = this.history.findIndex(function (item) { return item.fen === prevFen; });
        
        if(index < 0){        
          console.log("previous fen not in history");
          this.history.push({ genSan: san, fen: fen });        
        }else {
          console.log("previous in history, trimming");
          this.history = this.history.slice(0, index + 1);
          this.history.push({ genSan: san, fen: fen });
        }
      }

      this.getSelectedHistory();      
      this.prompieces = [];
      this.prompiecesext = [];
      this.setUp();

      var event = {
        kind: "moveplayed",
        prevFen: prevFen,
        fen: fen,
        genSan: san,
        variant: this.pos.pos.rules,
        history: this.history,
      };

      this.$emit("moveplayed", event);
    },
    prompiececlicked: function prompiececlicked(ev){
      var piece = ev.target.getAttribute("piece");
      var uci = this.promuci + piece;
      var san = this.pos.uciToSan(uci);
      this.$refs.movetextinput.value = san;
      this.showpromotion = false;
    },
    makemove: function makemove(){
      var fen = this.pos.reportFen();
      var move = this.$refs.movetextinput.value;
      this.$refs.movetextinput.value = "";
      try {
        this.pos.playSan(move);
        this.recordMovePlayed(move, fen);
      }catch(err){
        try{
          var san = this.pos.uciToSan(move);
          this.pos.playSan(san);
          this.recordMovePlayed(san, fen);          
        }catch(err){
          window.alert(("Illegal move " + move + " !"));
          return
        }
      }
    },
    variantchanged: function variantchanged(){      
      var variant = this.$refs.variantselect.value;      
      this.pos.setVariant(variant);      
      this.history = [];      
      this.recordMovePlayed("*", null);        
    },
    reset: function reset(){
      this.variantchanged();
    },
    clicksan: function clicksan(ev){
      var fen = this.pos.reportFen();
      var san = ev.target.getAttribute("san");      
      this.pos.playSan(san);
      this.recordMovePlayed(san, fen);
    },
    setUp: function setUp(){
      var fen = this.pos.reportFen();
      this.$refs.fentextinput.value = fen;
      var config = {
          fen: fen,        
          movable: { events: { after: this.movePlayed() } },
      };
      this.board = chessground.Chessground(this.$refs.board, config);      
      this.legalsans = this.pos.allLegalSans();      
    },
    movePlayed: function movePlayed(){
      var this$1$1 = this;

      return function (orig, dest, metadata) {
        var fen = this$1$1.pos.reportFen();
        var uci = "" + orig + dest;        
        var legals = this$1$1.pos.legalsForUci(uci);
        var num = legals.length;
        if(!num){
          window.alert(("Illegal move " + uci + " !"));
          this$1$1.$refs.movetextinput.value = "";
          this$1$1.showpromotion = false;
          this$1$1.setUp();
          return
        }
        if(num > 1){
          // handle promotion
          this$1$1.prompieces = legals.map(function (legal) { return legal.substring(4, 5); });
          this$1$1.prompiecesext = this$1$1.prompieces.map(function (p) { return ({
            p: p,
            klass: "prompiecediv " + this$1$1.pieceToStyle(p, this$1$1.pos.reportFen())              
          }); });
          this$1$1.showpromotion = true;          
          this$1$1.$refs.movetextinput.value = "Press piece !";
          this$1$1.promuci = uci;          
          return
        }
        this$1$1.$refs.movetextinput.value = "";
        this$1$1.showpromotion = false;
        var san = this$1$1.pos.uciToSan(uci);
        this$1$1.pos.playUci(uci);        
        this$1$1.recordMovePlayed(san, fen);        
      }
    }
  },
  mounted: function mounted(){    
    this.variantchanged();    
  },
  components:{

  }
};function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    var options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    var hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            var originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            var existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}/* script */
var __vue_script__ = script;
/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"vuechessground"},[_vm._ssrNode("<div class=\"horizcont\"><div class=\"vertcont\"><div class=\"moveinputdiv\"><input type=\"text\" class=\"movetextinput\"> "+((_vm.showpromotion)?("<div class=\"prompiecebuttons\">"+(_vm._ssrList((_vm.prompiecesext),function(prompieceext){return ("<div"+(_vm._ssrAttr("piece",prompieceext.p))+(_vm._ssrClass(null,prompieceext.klass))+">"+_vm._ssrEscape("\n            "+_vm._s(prompieceext.p.toUpperCase())+"\n          ")+"</div>")}))+"</div>"):"<!---->")+" <button>Make Move</button> <button>Cancel</button></div> <div class=\"blue merida\"><div class=\"cg-board-wrap\"></div></div> <div class=\"fendiv\"><input tytpe=\"text\" class=\"fentextinput\"></div> <div class=\"controls\"><button>|&lt;</button> <button>&lt;</button> <button>&gt;</button> <button>&gt;|</button> <button>Reset</button> <select>"+(_vm._ssrList((_vm.variants),function(variant){return ("<option"+(_vm._ssrAttr("value",variant.key))+">"+_vm._ssrEscape(_vm._s(variant.display))+"</option>")}))+"</select></div></div> <div class=\"legalsans\">"+(_vm._ssrList((_vm.legalsans),function(item){return ("<div><div"+(_vm._ssrAttr("san",item))+" class=\"legalsan\">"+_vm._ssrEscape("\n          "+_vm._s(item)+"\n        ")+"</div></div>")}))+"</div> <div class=\"historysans\">"+(_vm._ssrList((_vm.history),function(item){return ("<div"+(_vm._ssrAttr("fen",item.fen))+(_vm._ssrClass("historysan",item.selected))+">"+_vm._ssrEscape("            \n        "+_vm._s(item.genSan)+"          \n      ")+"</div>")}))+"</div></div>")])};
var __vue_staticRenderFns__ = [];

  /* style */
  var __vue_inject_styles__ = undefined;
  /* scoped */
  var __vue_scope_id__ = undefined;
  /* module identifier */
  var __vue_module_identifier__ = "data-v-7389251d";
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  var __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    undefined,
    undefined,
    undefined
  );// install function executed by Vue.use()
function install(Vue) {
  if (install.installed) { return; }
  install.installed = true;
  Vue.component('Vuechessground', __vue_component__);
}

// Create module definition for Vue.use()
var plugin = {
  install: install,
};

// To auto-install when vue is found
var GlobalVue = null;
if (typeof window !== 'undefined') {
  GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
  GlobalVue = global.Vue;
}
if (GlobalVue) {
  GlobalVue.use(plugin);
}

// Inject install function into component - allows component
// to be registered via Vue.use() as well as Vue.component()
__vue_component__.install = install;

// It's possible to expose named exports when writing components that can
// also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
// export const RollupDemoDirective = component;
exports["default"]=__vue_component__;//# sourceMappingURL=vuechessground.ssr.js.map
